Control
=======

Instances of `Controls` are created via the :py:func:`contamxpy.prjDataReadyFcnP` callback function. If the callback function is called as indicated via the :py:class:`cxLib` constructor, then `Controls` will will be accessible via the :py:attr:`contamxpy.cxLib.inputControls` and :py:attr:`contamxpy.cxLib.outputControls` lists.


.. autoclass:: contamxpy.Control
    :members:

.. autoclass:: contamxpy.InputControl
    :members:

.. autoclass:: contamxpy.OutputControl
    :members:
